@@ -2,15 +2,85 @@ package Pinto::Server;
 
 # ABSTRACT: Web interface to a Pinto repository
 
-use strict;
-use warnings;
+use Moose;
+
+use Carp;
+use Path::Class;
+use File::Temp;
+
+use Pinto 0.023;
+
+use Pinto::Types qw(Dir);
+use MooseX::Types::Moose qw(Int Bool);
+use Pinto::Server::Routes;
+use Dancer qw(:moose :script);
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 
 #-----------------------------------------------------------------------------
 
+
+has repos => (
+    is       => 'ro',
+    isa      => Dir,
+    coerce   => 1,
+    required => 1,
+);
+
+#-----------------------------------------------------------------------------
+
+
+has port => (
+    is       => 'ro',
+    isa      => Int,
+    default  => 3000,
+);
+
+#-----------------------------------------------------------------------------
+
+
+has daemon => (
+    is       => 'ro',
+    isa      => Bool,
+    default  => 0,
+);
+
+#-----------------------------------------------------------------------------
+
+
+sub run {
+    my ($self) = @_;
+
+    Dancer::set( repos  => $self->repos()  );
+    Dancer::set( port   => $self->port()   );
+    Dancer::set( daemon => $self->daemon() );
+    Dancer::set( logger => 'console'       );
+    Dancer::set( log    => 'debug'         );
+
+    $self->_initialize();
+    return Dancer::dance();
+}
+
+#-----------------------------------------------------------------------------
+
+sub _initialize {
+    my ($self) = @_;
+
+    print 'Initializing pinto ... ';
+    my $pinto = Pinto::Server::Routes::pinto();
+    $pinto->new_action_batch(noinit => 0);
+    $pinto->add_action('Nop');
+    my $result = $pinto->run_actions();
+    die "\n" . $result->to_string() . "\n" if not $result->is_success();
+    print "Done\n";
+
+    return $self;
+}
+
+#----------------------------------------------------------------------------
+
 1;
 
 
@@ -27,7 +97,7 @@ Pinto::Server - Web interface to a Pinto repository
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 DESCRIPTION
 
@@ -39,6 +109,28 @@ Then you'll probably want to look at L<pinto-remote>.
 
 See L<Pinto::Manual> for a complete guide.
 
+=head1 ATTRIBUTES
+
+=head2 repos
+
+The path to your Pinto repository.  The repository must already exist
+at this location.  This attribute is required.
+
+=head2 port
+
+The port number the server shall listen on.  The default is 3000.
+
+=head2 daemon
+
+If true, Pinto::Server will fork and run in a separate process.
+Default is false.
+
+=head1 METHODS
+
+=head2 run()
+
+Starts the Pinto::Server.  Returns a PSGI-compatible code reference.
+
 =head1 SUPPORT
 
 =head2 Perldoc
